# What is this?

A game for Code Quest 22.

If you are competing, you should have recieved a document containing all the documentation required. Please refer to that.

# Contributing

    pip install -e ./

    codequest22 -h

# Building

    pip install twine

    python setup.py sdist bdist_wheel

    twine upload dist/*
